==> nuxt-graphql-middleware-1.1.7.tgz: package/lib/esm/module/codegen.js <==
import path from 'path';
import { generate } from '@graphql-codegen/cli';
import * as PluginTypescript from '@graphql-codegen/typescript';
import * as PluginTypescriptOperations from '@graphql-codegen/typescript-operations';
import * as PluginSchemaAst from '@graphql-codegen/schema-ast';
const typescriptConfig = {
    exportFragmentSpreadSubTypes: true,
    preResolveTypes: true,
    skipTypeNameForRoot: true,
};
function pluginLoader(name) {
    if (name === '@graphql-codegen/typescript') {
        return Promise.resolve(PluginTypescript);
    }
    else if (name === '@graphql-codegen/typescript-operations') {
        return Promise.resolve(PluginTypescriptOperations);
    }
    else {
        return Promise.resolve(PluginSchemaAst);
    }
}
export default function (graphqlServer, options) {
    const schemaPath = path.resolve(options.schemaOutputPath, 'schema.graphql');
    function generateSchema() {
        const schema = options.skipSchemaDownload
            ? schemaPath
            : { [graphqlServer]: options.schemaOptions };
        return generate({
            schema,
            pluginLoader,
            generates: {
                [schemaPath]: {
                    plugins: [{ 'schema-ast': typescriptConfig }],
                    config: typescriptConfig,
                },
                [path.resolve(options.typesOutputPath, 'graphql-schema.d.ts')]: {
                    plugins: [{ typescript: typescriptConfig }],
                    config: typescriptConfig,
                },
            },
        }, true);
    }
    function generateTypes() {
        const config = Object.assign(Object.assign({}, typescriptConfig), { onlyOperationTypes: true });
        return generate({
            schema: schemaPath,
            pluginLoader,
            documents: path.resolve(options.resolvedQueriesPath, './*.graphql'),
            generates: {
                [path.resolve(options.typesOutputPath, 'graphql-operations.d.ts')]: {
                    plugins: ['typescript', { 'typescript-operations': config }],
                    config,
                },
            },
        }, true);
    }
    return { generateSchema, generateTypes };
}

==> nuxt-graphql-middleware-1.2.2.tgz: package/lib/esm/module/codegen.js <==
import path from 'path';
import { generate } from '@graphql-codegen/cli';
import * as PluginTypescript from '@graphql-codegen/typescript';
import * as PluginTypescriptOperations from '@graphql-codegen/typescript-operations';
import * as PluginSchemaAst from '@graphql-codegen/schema-ast';
const typescriptConfig = {
    exportFragmentSpreadSubTypes: true,
    preResolveTypes: true,
    skipTypeNameForRoot: true,
};
function pluginLoader(name) {
    if (name === '@graphql-codegen/typescript') {
        return Promise.resolve(PluginTypescript);
    }
    else if (name === '@graphql-codegen/typescript-operations') {
        return Promise.resolve(PluginTypescriptOperations);
    }
    else {
        return Promise.resolve(PluginSchemaAst);
    }
}
export default function (graphqlServer, options) {
    const schemaPath = path.resolve(options.schemaOutputPath, 'schema.graphql');
    function generateSchema() {
        const schema = options.skipSchemaDownload
            ? schemaPath
            : { [graphqlServer]: options.schemaOptions };
        const configSchemaAst = Object.assign(Object.assign({}, typescriptConfig), { sort: true });
        return generate({
            schema,
            pluginLoader,
            generates: {
                [schemaPath]: {
                    plugins: [{ 'schema-ast': configSchemaAst }],
                    config: configSchemaAst,
                },
                [path.resolve(options.typesOutputPath, 'graphql-schema.d.ts')]: {
                    plugins: [{ typescript: typescriptConfig }],
                    config: typescriptConfig,
                },
            },
        }, true);
    }
    function generateTypes() {
        const config = Object.assign(Object.assign({}, typescriptConfig), { onlyOperationTypes: true });
        return generate({
            schema: schemaPath,
            pluginLoader,
            documents: path.resolve(options.resolvedQueriesPath, './*.graphql'),
            generates: {
                [path.resolve(options.typesOutputPath, 'graphql-operations.d.ts')]: {
                    plugins: ['typescript', { 'typescript-operations': config }],
                    config,
                },
            },
        }, true);
    }
    return { generateSchema, generateTypes };
}
